import React, { useEffect, useState } from "react";
import axios from "axios";

const MyProfile = () => {
  const [profileData, setProfileData] = useState(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState("");

  useEffect(() => {
    const fetchProfileData = async () => {
      const peopleId = localStorage.getItem("peopleId");

      // return early if no people id is found
      if (!peopleId) {
        setError("No people ID found!");
        setLoading(false);
        return;
      }

      try {
        const response = await axios.get(
          `${process.env.REACT_APP_API_URL}/person/fullInfo/${peopleId}`
        );
        setProfileData(response.data.person);
        setLoading(false);
      } catch (err) {
        setError("Failed to fetch profile data.");
        setLoading(false);
        console.error(err);
      }
    };

    fetchProfileData();
  }, []);

  if (loading) return <p>Loading your profile...</p>;
  if (error) return <p>{error}</p>;

  return (
    <div className="my-profile">
      <h1>My Profile</h1>

      {/* Personal Information */}
      <section>
        <h2>Personal Information</h2>
        <p>
          <strong>First Name:</strong>{" "}
          {profileData.personalInformation.firstName}
        </p>
        <p>
          <strong>Last Name:</strong> {profileData.personalInformation.lastName}
        </p>
        <p>
          <strong>Middle Name:</strong>{" "}
          {profileData.personalInformation.middleName}
        </p>
        <p>
          <strong>Maiden Name:</strong>{" "}
          {profileData.personalInformation.maidenName || "N/A"}
        </p>
        <p>
          <strong>Nickname:</strong> {profileData.personalInformation.nickName}
        </p>
        <p>
          <strong>Gender:</strong> {profileData.personalInformation.gender}
        </p>
        <p>
          <strong>Class Year:</strong>{" "}
          {profileData.personalInformation.classYear}
        </p>
        <p>
          <strong>Graduation Year:</strong>{" "}
          {profileData.personalInformation.gradYear}
        </p>
        <p>
          <strong>Graduation Semester:</strong>{" "}
          {profileData.personalInformation.gradSemester}
        </p>
        <p>
          <strong>Alumni Chapter:</strong>{" "}
          {profileData.personalInformation.techAlumniChapter}
        </p>
      </section>

      {/* Degree Information */}
      <section>
        <h2>Degree Information</h2>
        {profileData.degreeInformation.map((degree, index) => (
          <div key={degree.peopleDegreeId || index}>
            <p>
              <strong>Degree Type:</strong> {degree.degreeType || "N/A"}
            </p>
            <p>
              <strong>Degree Department:</strong> {degree.degreeDepartment}
            </p>
            <p>
              <strong>Degree College:</strong> {degree.degreeCollege}
            </p>
            <p>
              <strong>Degree Year:</strong> {degree.degreeYear}
            </p>
            <p>
              <strong>Degree Description:</strong> {degree.degreeDescription}
            </p>
          </div>
        ))}
      </section>

      {/* Address Information */}
      <section>
        <h2>Address Information</h2>
        {profileData.addressInformation.length > 0 ? (
          profileData.addressInformation.map((address, index) => (
            <div key={index}>
              <p>
                <strong>Address 1:</strong> {address.address1}
              </p>
              <p>
                <strong>Address 2:</strong> {address.address2}
              </p>
              <p>
                <strong>City:</strong> {address.city}
              </p>
              <p>
                <strong>State:</strong> {address.state}
              </p>
              <p>
                <strong>Country:</strong> {address.country}
              </p>
              <p>
                <strong>Zip Code:</strong> {address.zipCode}
              </p>
              <p>
                <strong>Preferred Address:</strong>{" "}
                {address.preferredAddress ? "Yes" : "No"}
              </p>
            </div>
          ))
        ) : (
          <p>No address information available.</p>
        )}
      </section>

      {/* Contact Information */}
      <section>
        <h2>Contact Information</h2>
        {profileData.contactInformation.map((contact, index) => (
          <div key={contact.peopleContactId || index}>
            <p>
              <strong>Contact Number:</strong> {contact.contactNumber}
            </p>
            <p>
              <strong>Contact Type:</strong> {contact.contactType}
            </p>
            <p>
              <strong>Preferred Contact:</strong>{" "}
              {contact.preferredContact ? "Yes" : "No"}
            </p>
          </div>
        ))}
      </section>

      {/* Involvement Information */}
      <section>
        <h2>Involvement Information</h2>
        {profileData.involvmentInformation.length > 0 ? (
          <ul>
            {profileData.involvmentInformation.map((involvement, index) => (
              <li key={index}>{involvement}</li>
            ))}
          </ul>
        ) : (
          <p>No involvement information available.</p>
        )}
      </section>
    </div>
  );
};

export default MyProfile;
